@@ -8,9 +8,9 @@ use Log::ger;
 use Perinci::Object;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-07'; # DATE
+our $DATE = '2023-02-10'; # DATE
 our $DIST = 'App-PDFUtils'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our %SPEC;
 
@@ -26,6 +26,18 @@ my %argspec0_files = (
     },
 );
 
+my %argspec0_files__epub = (
+    files => {
+        schema => ['array*', of=>'filename*', min_len=>1,
+                   #uniq=>1, # not yet implemented by Data::Sah
+               ],
+        req => 1,
+        pos => 0,
+        slurpy => 1,
+        'x.element_completion' => [filename => {filter => sub { /\.epub$/i }}],
+    },
+);
+
 our %argspec0_file = (
     file => {
         summary => 'Input file',
@@ -508,6 +520,70 @@ sub compress_pdf {
     $envres->as_struct;
 }
 
+$SPEC{convert_epub_to_pdf} = {
+    v => 1.1,
+    summary => 'Convert epub file to PDF',
+    description => <<'_',
+
+This utility is a simple wrapper to `ebook-convert`. It allows setting output
+filenames (`foo.epub.pdf`) so you don't have to specify them manually. It also
+allows processing multiple files in a single invocation
+
+_
+    args => {
+        %argspec0_files__epub,
+        %argspecopt_overwrite,
+    },
+    deps => {
+        prog => 'ebook-convert',
+    },
+};
+sub convert_epub_to_pdf {
+    my %args = @_;
+
+    require IPC::System::Options;
+
+    my $envres = envresmulti();
+
+    my $i = 0;
+    for my $input_file (@{ $args{files} }) {
+        log_info "[%d/%d] Processing file %s ...", ++$i, scalar(@{ $args{files} }), $input_file;
+        $input_file =~ /(.+)\.(\w+)\z/ or do {
+            $envres->add_result(412, "Please supply input file with extension in its name (e.g. foo.epub instead of foo)", {item_id=>$input_file});
+            next;
+        };
+        my ($name, $ext) = ($1, $2);
+        $ext =~ /\Aepub\z/i or do {
+            $envres->add_result(412, "Input file '$input_file' does not have .epub extension", {item_id=>$input_file});
+            next;
+        };
+
+        my $output_file = "$input_file.pdf";
+
+        if (-e $output_file) {
+            if ($args{overwrite}) {
+                log_info "Unlinking existing PDF file %s ...", $output_file;
+                unlink $output_file;
+            } else {
+                $envres->add_result(412, "Output file '$output_file' already exists, not overwriting (use --overwrite (-O) to overwrite)", {item_id=>$input_file});
+                next;
+            }
+        }
+
+        IPC::System::Options::system(
+            {log=>1},
+            "ebook-convert", $input_file, $output_file);
+        my $exit_code = $? < 0 ? $? : $? >> 8;
+        if ($exit_code) {
+            $envres->add_result(500, "ebook-convert didn't return successfully, exit code=$exit_code", {item_id=>$input_file});
+        } else {
+            $envres->add_result(200, "OK", {item_id=>$input_file});
+        }
+    } # for $input_file
+
+    $envres->as_struct;
+}
+
 1;
 # ABSTRACT: Command-line utilities related to PDF files
 
@@ -523,7 +599,7 @@ App::PDFUtils - Command-line utilities related to PDF files
 
 =head1 VERSION
 
-This document describes version 0.014 of App::PDFUtils (from Perl distribution App-PDFUtils), released on 2022-10-07.
+This document describes version 0.015 of App::PDFUtils (from Perl distribution App-PDFUtils), released on 2023-02-10.
 
 =head1 SYNOPSIS
 
@@ -536,6 +612,10 @@ files:
 
 =item * L<compress-pdf>
 
+=item * L<convert-epub-to-pdf>
+
+=item * L<epub2pdf>
+
 =item * L<grep-from-pdf>
 
 =item * L<less-pdf-text>
@@ -576,8 +656,12 @@ Whether to backup the original file to ORIG~.
 
 =item * B<files>* => I<array[filename]>
 
+(No description)
+
 =item * B<password>* => I<str>
 
+(No description)
+
 
 =back
 
@@ -618,10 +702,58 @@ Arguments ('*' denotes required arguments):
 
 =item * B<files>* => I<array[filename]>
 
+(No description)
+
 =item * B<overwrite> => I<bool>
 
+(No description)
+
 =item * B<setting> => I<str> (default: "ebook")
 
+(No description)
+
+
+=back
+
+Returns an enveloped result (an array).
+
+First element ($status_code) is an integer containing HTTP-like status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
+
+Return value:  (any)
+
+
+
+=head2 convert_epub_to_pdf
+
+Usage:
+
+ convert_epub_to_pdf(%args) -> [$status_code, $reason, $payload, \%result_meta]
+
+Convert epub file to PDF.
+
+This utility is a simple wrapper to C<ebook-convert>. It allows setting output
+filenames (C<foo.epub.pdf>) so you don't have to specify them manually. It also
+allows processing multiple files in a single invocation
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<files>* => I<array[filename]>
+
+(No description)
+
+=item * B<overwrite> => I<bool>
+
+(No description)
+
 
 =back
 
@@ -674,6 +806,8 @@ Output path.
 
 =item * B<overwrite> => I<bool>
 
+(No description)
+
 =item * B<pages> => I<uint_range>
 
 Only convert a range of pages.
@@ -726,6 +860,8 @@ Input file.
 
 =item * B<quiet> => I<bool>
 
+(No description)
+
 
 =back
 
@@ -784,8 +920,12 @@ Whether to backup the original file to ORIG~.
 
 =item * B<files>* => I<array[filename]>
 
+(No description)
+
 =item * B<passwords> => I<array[str]>
 
+(No description)
+
 
 =back
 
@@ -836,7 +976,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2021, 2020, 2017 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2021, 2020, 2017 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
